@@ -5,6 +5,7 @@ context("expr_t_nonparametric")
 testthat::test_that(
   desc = "expr_t_nonparametric works - between-subjects design",
   code = {
+    testthat::skip_if(getRversion() < "3.6")
 
     # ggstatsplot output
     set.seed(123)
@@ -15,7 +16,7 @@ testthat::test_that(
         y = length,
         k = 3,
         conf.level = 0.90,
-        messages = FALSE
+        messages = TRUE
       )
 
     # expected output
@@ -58,6 +59,7 @@ testthat::test_that(
 testthat::test_that(
   desc = "expr_t_nonparametric works - within-subjects design",
   code = {
+    testthat::skip_if(getRversion() < "3.6")
 
     # made up data
     Input <- ("
@@ -112,7 +114,7 @@ testthat::test_that(
         conf.type = "perc",
         conf.level = 0.99,
         paired = TRUE,
-        messages = FALSE
+        messages = TRUE
       ))
 
     # expected output
