@@ -5,50 +5,54 @@ context("expr_t_robust")
 testthat::test_that(
   desc = "expr_t_robust - within-subjects - without NAs",
   code = {
+    testthat::skip_if(getRversion() < "3.6")
+
     # subtitle
     set.seed(123)
-    using_function1 <- expr_t_robust(
-      data = dplyr::filter(
-        statsExpressions::iris_long,
-        condition %in% c("Sepal.Length", "Sepal.Width")
-      ),
-      x = "condition",
-      y = value,
-      paired = TRUE,
-      conf.level = 0.90,
-      k = 4,
-      messages = FALSE
-    )
+    using_function1 <-
+      expr_t_robust(
+        data = dplyr::filter(
+          statsExpressions::iris_long,
+          condition %in% c("Sepal.Length", "Sepal.Width")
+        ),
+        x = "condition",
+        y = value,
+        paired = TRUE,
+        conf.level = 0.90,
+        k = 4,
+        messages = FALSE
+      )
 
     # expected
-    results1 <- ggplot2::expr(
-      paste(
-        NULL,
-        italic("t"),
-        "(",
-        "119",
-        ") = ",
-        "31.9809",
-        ", ",
-        italic("p"),
-        " = ",
-        "< 0.001",
-        ", ",
-        italic(xi),
-        " = ",
-        "0.9265",
-        ", CI"["90%"],
-        " [",
-        "0.9193",
-        ", ",
-        "0.9367",
-        "]",
-        ", ",
-        italic("n")["pairs"],
-        " = ",
-        150L
+    results1 <-
+      ggplot2::expr(
+        paste(
+          NULL,
+          italic("t"),
+          "(",
+          "119",
+          ") = ",
+          "31.9809",
+          ", ",
+          italic("p"),
+          " = ",
+          "< 0.001",
+          ", ",
+          italic(xi),
+          " = ",
+          "0.9265",
+          ", CI"["90%"],
+          " [",
+          "0.9193",
+          ", ",
+          "0.9367",
+          "]",
+          ", ",
+          italic("n")["pairs"],
+          " = ",
+          150L
+        )
       )
-    )
 
     # testing overall call
     testthat::expect_identical(using_function1, results1)
@@ -82,6 +86,8 @@ testthat::test_that(
 testthat::test_that(
   desc = "expr_t_robust - within-subjects - with NAs",
   code = {
+    testthat::skip_if(getRversion() < "3.6")
+
     # subtitle
     set.seed(123)
     using_function1 <- expr_t_robust(
@@ -135,49 +141,51 @@ testthat::test_that(
 testthat::test_that(
   desc = "expr_t_robust - between-subjects - without NAs",
   code = {
-
+    testthat::skip_if(getRversion() < "3.6")
 
     # subtitle
     set.seed(123)
-    using_function1 <- expr_t_robust(
-      data = mtcars,
-      x = am,
-      y = "wt",
-      paired = FALSE,
-      conf.level = 0.99,
-      k = 3,
-      messages = FALSE
-    )
+    using_function1 <-
+      expr_t_robust(
+        data = mtcars,
+        x = am,
+        y = "wt",
+        paired = FALSE,
+        conf.level = 0.99,
+        k = 3,
+        messages = FALSE
+      )
 
     # expected
-    results1 <- ggplot2::expr(
-      paste(
-        NULL,
-        italic("t"),
-        "(",
-        "24.816",
-        ") = ",
-        "5.255",
-        ", ",
-        italic("p"),
-        " = ",
-        "< 0.001",
-        ", ",
-        italic(xi),
-        " = ",
-        "0.812",
-        ", CI"["99%"],
-        " [",
-        "0.699",
-        ", ",
-        "0.986",
-        "]",
-        ", ",
-        italic("n")["obs"],
-        " = ",
-        32L
+    results1 <-
+      ggplot2::expr(
+        paste(
+          NULL,
+          italic("t"),
+          "(",
+          "24.816",
+          ") = ",
+          "5.255",
+          ", ",
+          italic("p"),
+          " = ",
+          "< 0.001",
+          ", ",
+          italic(xi),
+          " = ",
+          "0.812",
+          ", CI"["99%"],
+          " [",
+          "0.699",
+          ", ",
+          "0.986",
+          "]",
+          ", ",
+          italic("n")["obs"],
+          " = ",
+          32L
+        )
       )
-    )
 
     # testing overall call
     testthat::expect_identical(using_function1, results1)
