@@ -5,52 +5,55 @@ context("expr_templates")
 testthat::test_that(
   desc = "checking if subtitle template works without any parameter",
   code = {
+    testthat::skip_if(getRversion() < "3.6")
 
     # subtitle
     set.seed(123)
-    subtitle <- ggplot2::expr(
-      paste(
-        NULL,
-        italic("W"),
-        " = ",
-        "8.74",
-        ", ",
-        italic("p"),
-        " = ",
-        "0.013",
-        ", ",
-        italic("r"),
-        " = ",
-        "0.52",
-        ", CI"["99%"],
-        " [",
-        "0.13",
-        ", ",
-        "0.93",
-        "]",
-        ", ",
-        italic("n"),
-        " = ",
-        32
+    subtitle <-
+      ggplot2::expr(
+        paste(
+          NULL,
+          italic("W"),
+          " = ",
+          "8.74",
+          ", ",
+          italic("p"),
+          " = ",
+          "0.013",
+          ", ",
+          italic("r"),
+          " = ",
+          "0.52",
+          ", CI"["99%"],
+          " [",
+          "0.13",
+          ", ",
+          "0.93",
+          "]",
+          ", ",
+          italic("n"),
+          " = ",
+          32
+        )
       )
-    )
 
     # created using a template maker
-    template_0 <- statsExpressions::expr_template(
-      no.parameters = 0L,
-      statistic.text = quote(italic("W")),
-      statistic = 8.74,
-      parameter = NULL,
-      p.value = 0.013,
-      effsize.estimate = 0.52,
-      effsize.LL = 0.13,
-      effsize.UL = 0.93,
-      conf.level = 0.99,
-      k = 2L,
-      k.parameter = 0L,
-      n = 32,
-      effsize.text = quote(italic("r"))
-    )
+    template_0 <-
+      statsExpressions::expr_template(
+        no.parameters = 0L,
+        statistic.text = quote(italic("W")),
+        statistic = 8.74,
+        parameter = NULL,
+        p.value = 0.013,
+        effsize.estimate = 0.52,
+        effsize.LL = 0.13,
+        effsize.UL = 0.93,
+        conf.level = 0.99,
+        k = 2L,
+        k.parameter = 0L,
+        n = 32,
+        effsize.text = quote(italic("r"))
+      )
 
     # check if they are equivalent
     testthat::expect_identical(subtitle, template_0)
@@ -62,55 +65,57 @@ testthat::test_that(
 testthat::test_that(
   desc = "checking if subtitle template works with a single parameter",
   code = {
-
+    testthat::skip_if(getRversion() < "3.6")
 
     # subtitle
     set.seed(123)
-    subtitle <- ggplot2::expr(
-      paste(
-        NULL,
-        italic(chi)^2,
-        "(",
-        "2",
-        ") = ",
-        "8.74",
-        ", ",
-        italic("p"),
-        " = ",
-        "0.013",
-        ", ",
-        italic(V),
-        " = ",
-        "0.52",
-        ", CI"["99%"],
-        " [",
-        "0.13",
-        ", ",
-        "0.93",
-        "]",
-        ", ",
-        italic("n"),
-        " = ",
-        32
+    subtitle <-
+      ggplot2::expr(
+        paste(
+          NULL,
+          italic(chi)^2,
+          "(",
+          "2",
+          ") = ",
+          "8.74",
+          ", ",
+          italic("p"),
+          " = ",
+          "0.013",
+          ", ",
+          italic(V),
+          " = ",
+          "0.52",
+          ", CI"["99%"],
+          " [",
+          "0.13",
+          ", ",
+          "0.93",
+          "]",
+          ", ",
+          italic("n"),
+          " = ",
+          32
+        )
       )
-    )
 
     # created using a template maker
-    template_1 <- statsExpressions::expr_template(
-      no.parameters = 1L,
-      statistic.text = quote(italic(chi)^2),
-      statistic = 8.74,
-      parameter = 2,
-      p.value = 0.013,
-      effsize.estimate = 0.52,
-      effsize.LL = 0.13,
-      effsize.UL = 0.93,
-      conf.level = 0.99,
-      k = 2L,
-      k.parameter = 0L,
-      n = 32,
-      effsize.text = quote(italic(V))
-    )
+    template_1 <-
+      statsExpressions::expr_template(
+        no.parameters = 1L,
+        statistic.text = quote(italic(chi)^2),
+        statistic = 8.74,
+        parameter = 2,
+        p.value = 0.013,
+        effsize.estimate = 0.52,
+        effsize.LL = 0.13,
+        effsize.UL = 0.93,
+        conf.level = 0.99,
+        k = 2L,
+        k.parameter = 0L,
+        n = 32,
+        effsize.text = quote(italic(V))
+      )
 
     # check if they are equivalent
     testthat::expect_identical(subtitle, template_1)
@@ -139,40 +144,41 @@ testthat::test_that(
 testthat::test_that(
   desc = "checking if subtitle template works with two parameters",
   code = {
-
+    testthat::skip_if(getRversion() < "3.6")
 
     # subtitle
     set.seed(123)
-    subtitle <- ggplot2::expr(
-      paste(
-        NULL,
-        italic("F"),
-        "(",
-        "3",
-        ",",
-        "24.05",
-        ") = ",
-        "2.27",
-        ", ",
-        italic("p"),
-        " = ",
-        "0.107",
-        ", ",
-        omega["p"]^2,
-        " = ",
-        "0.00",
-        ", CI"["95%"],
-        " [",
-        "-0.08",
-        ", ",
-        "0.10",
-        "]",
-        ", ",
-        italic("n"),
-        " = ",
-        51L
+    subtitle <-
+      ggplot2::expr(
+        paste(
+          NULL,
+          italic("F"),
+          "(",
+          "3",
+          ",",
+          "24.05",
+          ") = ",
+          "2.27",
+          ", ",
+          italic("p"),
+          " = ",
+          "0.107",
+          ", ",
+          omega["p"]^2,
+          " = ",
+          "0.00",
+          ", CI"["95%"],
+          " [",
+          "-0.08",
+          ", ",
+          "0.10",
+          "]",
+          ", ",
+          italic("n"),
+          " = ",
+          51L
+        )
       )
-    )
 
     # created using a template maker
     template_1 <- statsExpressions::expr_template(
